/***********************************************************************/
// Titel     	: HAA-BUS
//----------------------------------------------------------------------
// Beschreibung	: Zusammenstellung relevanter Daten zur Anzeige und 
//				: externer Ansteuerung weiterer Elektronik der Hausalarmanlage
//----------------------------------------------------------------------
// Autor     	: P. Fuhsy
/***********************************************************************/

//-----------------------------Includes---------------------------------
#include <avr/io.h>			//allg. Ports
#include <stdlib.h>			//Standard-Lib
#include <stdbool.h>		//fr Bool-Variablen
#include "haa_bus.h"		//eigene Header
#include "uart.h"			//zur UART-bertragung
//----------------------------------------------------------------------

//-----------------------Konstanten / Variablen-------------------------
//Initialisierung der Bytes
uint8_t BAS	= 0;			//Basis Status
uint8_t SIR	= 0;			//Sirene Status
uint8_t REE	= 0;			//Reedkontakte Status
uint8_t AKL	= 0;			//Akkuspg beim laden
uint8_t AKN	= 0;			//Akkuspg beim nicht laden
uint8_t SWH	= 0;			//Software-Version Hauptversion
uint8_t SWN	= 0;			//Software-Version Nebenversion
uint8_t CHK	= 0;			//Checksumme


//----------------------------------------------------------------------

//--------------------------Funktionsdefinitionen-----------------------

void BAS_byte_schreiben (bool sab, bool alf, bool als, bool alm, bool val, bool kal)	//Statusmeldungen der Basis
{
	BAS = (sab << 5) | (alf << 4) | (als << 3) | (alm << 2) | (val << 1) | (kal << 0);
}
void SIR_byte_schreiben (bool sto)														//Statusmeldungen der Sirene
{
	SIR = (sto << 0);
}
void REE_byte_schreiben (bool *reed)													//Zustnde der Reedkontakte
{
	int wert = 0;
	for (int i=1; i <=32; i *= 2)
	{
	wert += *reed *i;				//Wertigkeit berechnen und dazu addieren
	reed++;			
	}
		
	REE = wert;	//Wert an REE bertragen
}
void AKL_byte_schreiben (uint8_t akl)													//letzte gemessene Akkuspannung mit Ladung speichern
{
	AKL = akl;
}
void AKN_byte_schreiben (uint8_t akn)													//letzte gemessene Akkuspannung ohne Ladung speichern
{
	AKN = akn;
}
void SWP_byte_schreiben (char swh, char swn)											//Software-Version des Projektes zusammensetzten
{
	SWH = swh;	//Wert im Byte aufteilen	
	SWN = swn;	//Wert im Byte aufteilen								
}
void Checksumme_bilden()																//Checksumme bilden
{
	CHK = BAS ^ SIR ^ REE ^ AKL ^ AKN ^ SWH ^ SWN;
}
bool Prot_UART_anz ()																	//Protokoll ber UART senden (formatiert zur Anzeige)
{	
	char wert_chr[5];			//Variable zum wandeln von Integer in Char	
	bool letzter_wert = false;	//um anzuzeigen ob der letzte Byte gesendet wurde
	static int sender = 0;
	
	//sender steht dafr, welche Stckelung gesendet werden soll ohne Prozess zu stren
	switch(sender)	
	{
	
	case 0:	
		//berschrift Byte 0	
		/*BAS - Status der Basis*/
		putString("---\n");										//optische Trennung
		putString("Byte0 (BAS)\n");								//berschrift
		sender++;												
	break;	
		
	case 1:						
		//KAL - Kontaktalarm
		putString("KAL-Kontaktalarm: ");						//berschrift
		BAS & (1<<KAL) ? putString("Ja") : putString("Nein");	//Auswertung, If-Kurzschreibweise
		putString("\n");										//Zeilenumbruch
		sender++;
	break;		
	
	case 2:			
		//VAL - Voralarm
		putString("VAL-Voralarm: ");							//berschrift
		BAS & (1<<VAL) ? putString("Ja") : putString("Nein");	//Auswertung, If-Kurzschreibweise
		putString("\n");										//Zeilenumbruch	
		sender++;		
	break;	
	
	case 3:			
		//ALM - Alarm
		putString("ALM-Alarm: ");								//berschrift
		BAS & (1<<ALM) ? putString("Ja") : putString("Nein");	//Auswertung, If-Kurzschreibweise
		putString("\n");										//Zeilenumbruch
		sender++;		
	break;
	
	case 4:			
		//ALS - Anlage Start
		putString("ALS-Anlage-Start: ");
		BAS & (1<<ALS) ? putString("Ja") : putString("Nein");	//Auswertung, If-Kurzschreibweise
		putString("\n");										//Zeilenumbruch	
		sender++;		
	break;		
	
	case 5:			
		//ALF - Anlage Scharf
		putString("ALF-Anlage-Scharf: ");
		BAS & (1<<ALF) ? putString("Ja") : putString("Nein");	//Auswertung, If-Kurzschreibweise
		putString("\n");										//Zeilenumbruch	
		sender++;	
	break;
	
	case 6:			
		//SAB - Sabotagekontakte
		putString("SAB-Sabotagealarm: ");
		BAS & (1<<SAB) ? putString("Ja") : putString("Nein");	//Auswertung, If-Kurzschreibweise
		putString("\n");										//Zeilenumbruch		
		sender++;											
	break;
	
	case 7:
		//berschrift Byte 1
		/*SIR - Status der Sirene*/
		putString("---\n");										//optsiche Trennung
		putString("Byte1 (SIR)\n");								//berschrift
		sender++;
	break;			
	
	case 8:	
		//STO - Strungssignal
		putString("STO-Stoerung: ");
		SIR & (1<<STO) ? putString("Ja") : putString("Nein");	//Auswertung, If-Kurzschreibweise
		putString("\n");										//Zeilenumbruch
		sender++;		
	break;
	
	case 9:		
		//berschrift Byte 2
		/*REE - Status der Reedkontakte*/
		putString("---\n");											//optsiche Trennung
		putString("Byte2 (REE)\n");									//berschrift	
		sender++;
	break;		
	
	case 10:
		//REE0-Reedkonatkt 0
		putString("REE0-Reedkontakt 0: ");
		REE & (1<<REE0) ? putString("offen") : putString("geschl.");	//Auswertung, If-Kurzschreibweise
		putString("\n");												//Zeilenumbruch
		sender++;	
	break;
	
	case 11:	
		//REE1-Reedkonatkt 1
		putString("REE1-Reedkontakt 1: ");
		REE & (1<<REE1) ? putString("offen") : putString("geschl.");	//Auswertung, If-Kurzschreibweise
		putString("\n");												//Zeilenumbruch
		sender++;
	break;
	
	case 12:		
		//REE2-Reedkonatkt 2
		putString("REE2-Reedkontakt 2: ");
		REE & (1<<REE2) ? putString("offen") : putString("geschl.");	//Auswertung, If-Kurzschreibweise
		putString("\n");												//Zeilenumbruch
		sender++;
	break;
	
	case 13:		
		//REE3-Reedkonatkt 3
		putString("REE3-Reedkontakt 3: ");
		REE & (1<<REE3) ? putString("offen") : putString("geschl.");	//Auswertung, If-Kurzschreibweise
		putString("\n");												//Zeilenumbruch
		sender++;
	break;
	
	case 14:		
		//REE4-Reedkonatkt 4
		putString("REE4-Reedkontakt 4: ");
		REE & (1<<REE4) ? putString("offen") : putString("geschl.");	//Auswertung, If-Kurzschreibweise
		putString("\n");												//Zeilenumbruch
		sender++;
	break;
	
	case 15:		
		//REE5-Reedkonatkt 5
		putString("REE5-Reedkontakt 5: ");
		REE & (1<<REE5) ? putString("offen") : putString("geschl.");	//Auswertung, If-Kurzschreibweise
		putString("\n");												//Zeilenumbruch
		sender++;
	break;
	
	case 16:
		//berschrift Byte 3
		/*AKL - Akkuspannung mit Ladung*/
		putString("---\n");											//optsiche Trennung
		putString("Byte3 (AKL)\n");									//berschrift
		sender++;
	break;

	case 17:		
		//AKL - Akkuspanung mit Ladung
		putString("Akkuspg m. Ladg: ");
		itoa(AKL, wert_chr, 10);									//von Integer in Char wandeln
		putString(wert_chr);
		putString(".0V");
		putString("\n");											//Zeilenumbruch
		sender++;
	break;
		
	case 18:
		//berschrift Byte 4
		/*AKN - Akkuspannung ohne Ladung*/
		putString("---\n");											//optsiche Trennung
		putString("Byte4 (AKN)\n");									//berschrift
		sender++;		
	break;
		
	case 19:		
		//AKN - Akkuspanung ohne Ladung
		putString("Akkuspg o. Ladg: ");
		itoa(AKN, wert_chr, 10);									//von Integer in Char wandeln
		putString(wert_chr);
		putString(".0V");
		putString("\n");											//Zeilenumbruch
		sender++;
	break;	

	case 20:	
// 		//berschrift Byte 5
// 		/*SWP - Software-Version Projektes*/
// 		putString("---\n");											//optsiche Trennung
// 		putString("Byte5 (SWP)\n");									//berschrift
// 		putString("SW-Version Prot: v");
		sender++;
	break;			

	case 21:
		//berschrift Byte 8
		/*CHK - Checksumme*/
		putString("---\n");
		putString("Byte8 (CHK)\n");
		putString("Checksumme: ");
		sender++;
	break;
	
	case 22:					
		//CHK - Checksumme
		Checksumme_bilden();
		itoa(CHK, wert_chr, 10);	//von Integer in Char wandeln
		putString(wert_chr);
		putString("\n");			//Zeilenumbruch	
		letzter_wert = true;
		sender = 0;					//Stckelung zrcksetzten
	break;
	}
	
	return letzter_wert;			//Rckgabe ob letzter Wert gesendet wurde
}
//----------------------------------------------------------------------
/*
	struct haab_byte0 {
		bool = alm;
		bool = als;
		bool = val;
	};	struct bas;

	bas.alm = true;
	bas.als = false;
*/		
