#ifndef _HAA_BUS_H_
#define _HAA_BUS_H_

//------------------------------Prototypen-------------------------------
void BAS_byte_schreiben (bool sab, bool alf, bool als, bool alm, bool val, bool kal);
void SIR_byte_schreiben (bool sto);
void REE_byte_schreiben (bool *reed);
void AKL_byte_schreiben (uint8_t akl);
void AKN_byte_schreiben (uint8_t akn);
void SWP_byte_schreiben (char swh, char swn);
void Chk_byte_schreiben();
bool Prot_UART_anz();
//----------------------------------------------------------------------

/**************************Bit-bersicht*********************************
Bit				7		6		5		4		3		2		1		0
Byte
0	BAS			-		-		SAB		ALF		ALS		ALM		VAL		KAL
1	SIR			-		-		-		-		-		-		-		STO
2	REE			-		-		REE5	REE4	REE3	REE2	REE1	REE0
3	AKL			128		64		32		16		8		4		2		1
4	AKN			128		64		32		16		8		4		2		1
5	SWH			H8		H4		H2		H1		N8		N4		N2		N1
6	SWN			H8		H4		H2		H1		N8		N4		N2		N1		
7	CHK			128		64		32		16		8		4		2		1
************************************************************************/
/*---------------------BAS - Status der Basis------------------------
Beschreibung: Die allgemeinen Statusmeldungen der Basis.
*/
extern uint8_t BAS;				//Byte
// #define Res.		 		7	//Reserve
// #define Res.		 		6	//Reserve
#define SAB			  		5	//Sabotagekontakte
#define ALF			  		4 	//Anlage Scharf
#define ALS			  		3 	//Anlage Start
#define ALM			  		2 	//Alarm
#define VAL			  		1 	//Voralarm
#define KAL			  		0 	//Kontaktalarm

/*---------------------SIR - Status der Sirene------------------------
Beschreibung: Die allgemeinen Statusmeldungen der Sirene.
*/
extern uint8_t SIR;				//Byte
// #define Res.		 		7	//Reserve
// #define Res.		 		6	//Reserve
// #define Res.		 		5	//Reserve
// #define Res.		 		4	//Reserve
// #define Res.		 		3	//Reserve
// #define Res.		 		2	//Reserve
// #define Res.		 		1	//Reserve
#define STO				  	0 	//Strungsmeldung

/*---------------------REE - Status der Reedkontakte------------------
Beschreibung: Die allgemeinen Statusmeldungen der Reedkontakte.
*/
extern uint8_t REE;				//Byte
// #define Res.		 		7	//Reserve
// #define Res.		 		6	//Reserve
#define REE5			  	5 	//Reedkontakt 5, Reserve
#define REE4			  	4 	//Reedkontakt 4, Reserve
#define REE3			  	3 	//Reedkontakt 3, obere Etage
#define REE2			  	2 	//Reedkontakt 2, Garage
#define REE1			  	1 	//Reedkontakt 1, Eingangsfenster
#define REE0			  	0 	//Reedkontakt 0, Eingangstr

/*--------------------------AKL - Akkuspannung 1---------------------
Beschreibung: Wert der Akkuspannung mit Ladung.
Wert: 0-255
*/
extern uint8_t AKL;				//Byte

/*--------------------------AKN - Akkuspannung 2---------------------
Beschreibung: Wert der Akkuspannung ohne Ladung
Wert: 0-255
*/
extern uint8_t AKN;				//Byte

/*------------------SWP - Software-Version Hauptversion--------------
Beschreibung: Hauptversion des Projektes
Wert: 0-255
*/
extern uint8_t SWH;				//Byte

/*------------------SWP - Software-Version Nebenversion--------------
Beschreibung: Hauptversion des Projektes
Wert: 0-255
*/
extern uint8_t SWN;				//Byte

/*--------------------------CHK - Checksumme-------------------------
Beschreibung: Bildung der Checksumme.
Wert: 0-255
*/
extern uint8_t CHK;				//Byte

#endif
