/***********************************************************************/
// Titel     	: UART
//----------------------------------------------------------------------
// Beschreibung	: Daten senden per UART-Schnittstelle des Controllers Atmega8
//----------------------------------------------------------------------
// Autor     	: P. Fuhsy
/***********************************************************************/

//-----------------------------Includes---------------------------------
#include <avr/io.h>								//allg. Ports
#include "uart.h"								//eigene Header
//----------------------------------------------------------------------

//-----------------------------Variablen--------------------------------
#define F_CPU			8000000UL		//CPU festlegen
#define BAUD			9600			//einstellte Baudrate
//----------------------------------------------------------------------

//UART-Schnittstelle initialisieren
void initUART()	
{
	UBRRL = (F_CPU / BAUD - 16) / 16; 			//Baudberchnnung
	UCSRB = (1<<RXEN)|(1<<TXEN)|(1<<RXCIE);		//Receiver Enable, Transmitter Enable,  RX Complete Interrupt Enable
	UCSRC = (1<<URSEL)|(1<<UCSZ1)|(1<<UCSZ0);	//Asynchron 8N1
}

//Zeichen senden
void putChar(char data)				
{
	while (!(UCSRA & (1<<UDRE)));				//warte bis der Sendepuffer leer ist
	UDR = data;									//senden
}

//ganze Strings senden
void putString(char *buffer)
{
	for (int i=0 ; buffer[i] !=0 ; i++)
		putChar(buffer[i]);
}

